<?php

/**
 * _ntm_m_get_names().
 * _ntm_t_get_names().
 */

function _ntm_m_get_names() {
  $names = menu_get_menus();
  return $names;
}


function _ntm_t_get_names() {
  $options = module_exists('taxonomy') ? taxonomy_vocabulary_get_names() : NULL;
  $names = array();
  if ($options) {
    foreach ($options as $item) {
      $names[$item->vid] = $item->name;
    }
  }
  return $names;
}


/**
 * _ntm_m_get_flat_tree().
 * _ntm_t_get_flat_tree().
 */

function _ntm_m_get_flat_tree($source_id, $iid = 0, $max_depth = NTM_MAX_DEPTH) {
  if ($iid) {
    $root_info = menu_link_load($iid);
  }
  $cache = &drupal_static('ntm_menu_cache', array());
  $cache_id = $source_id.$iid.$max_depth;
  if (!isset($cache[$cache_id])) {
    $cache[$cache_id] = menu_build_tree($source_id, array('max_depth' => (isset($root_info) ? $root_info['depth'] + $max_depth : $max_depth)));
  }
  $tree = $cache[$cache_id];
  if ($iid) {
    $tree = _ntm_m_get_sub_tree($tree, $iid);
    $tree = $tree['below'];
  }
  if ($tree) {
    $tree = _ntm_m_items_collect(menu_tree_output($tree));
    if (isset($root_info)) {
      foreach ($tree as $item) {
        $item->depth-= $root_info['depth'];
      }
    }
  }
  return $tree;
}


function _ntm_t_get_flat_tree($source_id, $iid = 0, $max_depth = NTM_MAX_DEPTH) {
  $tree = module_exists('taxonomy') ? taxonomy_get_tree($source_id, $iid, $max_depth) : NULL;
  if ($tree) {
    foreach ($tree as $node) {
      $node->depth++;
      $node->iid = $node->tid;
      $node->url = "taxonomy/term/$node->iid";
      $node->title = $node->name;
    }
  }
  return $tree;
}


/**
 * _ntm_flat_tree_render().
 */

function _ntm_flat_tree_render($flat_tree, $style = 'down') {
  $item_list = array();
  foreach ($flat_tree as $index => $c_item) {
    $new_item = array('data' => l($c_item->title, $c_item->url), 'children' => array());
    if (isset($flat_tree[$index+1]) && $flat_tree[$index+1]->depth == $c_item->depth+1) $new_item['class'] = array('has_child');
    if ($c_item->depth == 1) {
      $item_list[]= $new_item;
    } else {
      _ntm_item_list_add_child($item_list, $new_item, $c_item->depth-1);
    }
  }
  $item_list_html = theme('item_list', array('items' => $item_list));
  $item_list_html = str_replace(array('<div class="item-list">', '</div>'), '', $item_list_html);
  $item_list_html = str_replace('<ul class="has_child">', '<ul>', $item_list_html);
  return '<div class="menu-ntm menu-ntm-'.$style.' clearfix">'.$item_list_html.'</div>';
}


/**
 * support funcs
 */

function _ntm_item_list_add_child(&$elements, $child, $depth) {
  if ($depth > 1) {
    _ntm_item_list_add_child($elements[count($elements)-1]['children'], $child, $depth - 1);
  } else if ($depth == 1) {
    $elements[count($elements)-1]['children'][]= $child;
  }
}


function _ntm_m_get_sub_tree($tree, $iid) {
  foreach ($tree as $node) {
    if ($node['link'] && $node['link']['mlid'] == $iid) return $node;
    if ($node['below']) {
      $node = _ntm_m_get_sub_tree($node['below'], $iid);
      if ($node) return $node;
    }
  }
}


function _ntm_m_items_collect($tree, &$info = array()) {
  foreach ($tree as $node) {
    if (isset($node['#original_link'])) {
      $link = $node['#original_link'];
      if ($link['type'] == MENU_NORMAL_ITEM) {
        $info[]= (object)array(
          'iid'   => $link['mlid'],
          'url'   => $link['href'],
          'title' => $link['title'],
          'depth' => $link['depth'],
        );
      }
    }
    if (isset($node['#below'])) {
      _ntm_m_items_collect($node['#below'], $info);
    }
  }
  return $info;
}


